Documentation
¶
Overview ¶
Package tui provides the terminal user interface
Package tui provides the terminal user interface
Index ¶
Constants ¶
const ( ViewPlaylist = iota ViewLyrics ViewSyncedLyrics ViewArtist ViewComments ViewVisualizer ViewOff ViewModeCount )
Bottom view mode constants
const ( ModalNone = iota ModalOptions ModalSkipWarning ModalFavorites ModalGallery ModalStationWarning ModalRating ModalNetworkTransition ModalSleepTimer )
Modal types
const ( NetworkGoingOffline = iota NetworkGoingOnline )
Network transition variants
const ( LayoutLarge = iota LayoutMedium LayoutCompact LayoutNarrow )
Layout mode constants
const MaxPlaylistSize = 16
Variables ¶
This section is empty.
Functions ¶
func ClearImageAtCurrentPosition ¶ added in v1.1.0
ClearImageAtCurrentPosition returns the appropriate clear sequence for the given protocol to clear an image at the specified dimensions (in character cells). IMPORTANT: This function assumes the cursor is already positioned at the top-left of the image area. It clears only the rectangular image area, not entire rows. For Halfblocks, dimensions are stored as cells already (width/2, height/2 from app.go).
func ResetLayoutPrompt ¶
func ResetLayoutPrompt()
ResetLayoutPrompt resets the package-level layout prompt state
Types ¶
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model represents the main TUI application model
func NewModel ¶
func NewModel(cfg *config.Config, theme *config.ColorTheme, startJukebox bool, layoutOverride string, sleepTimerDuration time.Duration, audioForward bool) *Model
NewModel creates a new TUI model
func NewOfflineModel ¶
func NewOfflineModel(cfg *config.Config, theme *config.ColorTheme, songs []cache.CachedSong, cacheName string, layoutOverride string, audioForward bool) *Model
NewOfflineModel creates a new TUI model for offline playback
Directories
¶
| Path | Synopsis |
|---|---|
|
Package modals provides modal dialogs for the TUI
|
Package modals provides modal dialogs for the TUI |
|
Package visualizer provides audio spectrum visualization with multiple rendering modes.
|
Package visualizer provides audio spectrum visualization with multiple rendering modes. |
|
Package widgets provides reusable TUI components
|
Package widgets provides reusable TUI components |